@@ -123,9 +123,10 @@ Instantiates an object and connects to the LDAP server. Returns an object on suc
 
 =cut
 
-use vars qw($VERSION);
 #Define version
-$VERSION = '1.031';
+$OSS::LDAPops::VERSION = '1.032';
+
+
 
 #Please also note, proper error checking MUST be used to ensure
 #the integrity of the directory.
@@ -580,6 +581,42 @@ sub updatepw
 	$msg->code && return ($msg->error);
 };
 
+=head2 lockacct
+
+Lock a user account by setting shadowExpire to 1
+
+	$obj->lockacct(<uid>,[1|0]);
+
+1 locks, 0 unlocks. 
+
+=cut
+
+sub lockacct {
+	my($self) = shift;
+	my($uid) = shift;
+	my($lock) = shift;
+	my($msg);
+	if ($lock)
+	{
+                $msg = $self->{LDAPOBJ}->modify(
+                                "uid=$uid, ou=people,".$self->{BASEDN},
+                                replace => {
+                                                'shadowExpire' 		=> 1
+                                        }
+                        );
+
+	} else
+	{
+		$msg = $self->{LDAPOBJ}->modify( 
+				"uid=$uid, ou=people,".$self->{BASEDN},
+				replace	=> {
+						'shadowExpire' 		=> -1
+					}
+			);
+	}
+	$msg->code && return ($msg->error);
+};
+
 =head2 addusertoug
 
 Add a user entry to a user group
